@@ -10,7 +10,8 @@
 
 #include <QMainWindow>
 
-#include "../../widgetcapabilities/qorientationcapability.h"
+#include <qmaemo-ext/widget/qorientationcapability.h>
+#include <qmaemo-ext/notifications/qnotification.h>
 
 class QPushButton;
 class QMenu;
@@ -36,7 +37,6 @@ private:
     QMenu *menu;
     QAction *quitAction;
     QAction *orientationChangeModeAction;
-
-
+    Maemo::QNotifications *notification;
 };
 #endif
